@@ -295,11 +295,11 @@ as_rtf_footnote <- function(tbl, attr_name = "rtf_footnote") {
   }
 
   if (attr(text, "as_table")) {
-    indent <- unlist(
+    indent <- unlist(c(
       attr(text, "text_indent_first"),
       attr(text, "text_indent_left"),
       attr(text, "text_indent_right")
-    )
+    ))
 
     if (any(indent != 0)) {
       text_matrix <- matrix(text, ncol = 1)
