@@ -1,6 +1,4 @@
 library(testthat)
-library(dplyr)
 library(r2rtf)
-library(ggplot2)
 
 test_check("r2rtf")
